@@ -3,9 +3,9 @@ package Number::Phone::JP::Table::Class1;
 use strict;
 use warnings;
 
-our $VERSION = '0.20160105';
+our $VERSION = '0.20160201';
 
-# Table last modified: 2016-01-05
+# Table last modified: 2016-02-01
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
     '01'    => '\d+', # KDDI
@@ -16,8 +16,8 @@ our %TEL_TABLE = (
     '034'   => '\d+', # NTTコミュニケーションズ
     '035'   => '\d+', # NTTコミュニケーションズ
     '036'   => '\d+', # NTT東日本
-    '037'   => '\d+', # フュージョンコミュニケーションズ
-    '038'   => '\d+', # フュージョンコミュニケーションズ
+    '037'   => '\d+', # 楽天コミュニケーションズ
+    '038'   => '\d+', # 楽天コミュニケーションズ
     '039'   => '\d+', # NTT西日本
     '041'   => '\d+', # ソフトバンク
     '046'   => '\d+', # ソフトバンク
@@ -39,8 +39,8 @@ our %TEL_TABLE = (
     '073'   => '\d+', # 安子の電話
     '074'   => '\d+', # 安子の電話
     '077'   => '\d+', # KDDI
-    '081'   => '\d+', # フュージョンコミュニケーションズ
-    '082'   => '\d+', # フュージョンコミュニケーションズ
+    '081'   => '\d+', # 楽天コミュニケーションズ
+    '082'   => '\d+', # 楽天コミュニケーションズ
     '083'   => '\d+', # ソフトバンク
     '084'   => '\d+', # ソフトバンク
     '086'   => '\d+', # 九州通信ネットワーク
