@@ -3,14 +3,14 @@ package Number::Phone::JP::Table::Class2;
 use strict;
 use warnings;
 
-our $VERSION = '0.20160105';
+our $VERSION = '0.20160201';
 
-# Table last modified: 2016-01-05
+# Table last modified: 2016-02-01
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
     '09120'  => '\d+', # ブラステル
     '09121'  => '\d+', # ブラステル
-    '09130'  => '\d+', # ドコモ
+    '09130'  => '\d+', # NTTドコモ
     '09155'  => '\d+', # NTT-ME
     '09156'  => '\d+', # NTT-ME
     '09181'  => '\d+', # 関西コムネット
